/**
 *
 * This file is part of Tulip (www.tulip-software.org)
 *
 * Authors: David Auber and the Tulip development Team
 * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
 *
 * Tulip is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * Tulip is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 */
#ifndef _EqualValueClustering_H
#define _EqualValueClustering_H

#include <tulip/TulipPluginHeaders.h>

class EqualValueClustering:public tlp::Algorithm {
public:
  PLUGININFORMATION("Equal Value","David Auber","20/05/2008","Beta","1.1", "Clustering")
  EqualValueClustering(tlp::PluginContext* context);
  bool run();
};

#endif





